@@ -26,7 +26,7 @@ class URL:
         return self.url
 
 def model_to_data(model=None):
-    return tuple([i.data for i in model])
+    return tuple([i.data if hasattr(i, "data") else i for i in model])
 
 class table_objects:
     def __init__(self, obj=None):
@@ -46,7 +46,7 @@ class table_objects:
             if transit == need:
                 result.append(column)
         if len(result) != 1:
-            raise ValueError("未找到或找到了多个匹配的数据，如果你试图筛选多数据，请参考‘filter’.")
+            raise ValueError("找到了 %d 个匹配的数据，如果你试图筛选多数据，请参考‘filter’." % len(result))
         return result[0]
 
     def create(self, *args, **kwargs):
@@ -55,10 +55,9 @@ class table_objects:
             column = 0
         else:
             column = max(column) + 1
+
         self.obj.repo.make_folder(path=URL(self.obj.name)/column)
 
-        print(self.obj.namespace)
-        input("==="*10)
         datas = []
         for name in self.obj.namespace:
             if name == "id":
@@ -74,14 +73,6 @@ class table_objects:
             else:
                 raise ValueError("意料之外的参数: %s." % name)
 
-        """
-        for i in self.obj.namespace:
-            if name in kwargs:
-                self.obj.repo.upload_file(
-                    path = URL(self.obj.name) / column / i,
-                    content = json.dumps({"content": datas[i]})
-                    )
-        """
         self.obj.sync()
         return self.obj.columns
 
@@ -168,10 +159,7 @@ class SqleeColumn:
 
     @property
     def data(self):
-        result = []
-        for data in self.datas:
-            result.append(data.data)
-        return tuple(result)
+        return tuple(model_to_data(self.datas))
 
     @property
     def length(self):
@@ -181,31 +169,25 @@ class SqleeColumn:
         return len(self.data)
 
     def sync(self):
-        self.datas = []
-        datas = [self.id, ]
-        datas += list(self.repo.list_file(path="%s/%d" % (self.table.name, self.id), detail=True))
+        self.datas = [self.id, ]
+
+        datas = []
+        queries = list(self.repo.list_file(path="%s/%d" % (self.table.name, self.id), detail=True))
+        for query in queries:
+            if query["type"] == "file" and query["name"] != ".keep":
+                datas.append(query)
+
         for data in datas:
-            if isinstance(data, int):
-                continue
-            if data["name"] == ".keep":
-                del datas[datas.index(data)]
-        for data in datas:
-            if isinstance(data, int):
-                self.datas.append(
-                    SqleeData(data, url="id",
-                              namespace="id",
-                              repo=self.repo)
-                    )
-                continue
             loads = self.repo.get_data(path=data["path"])
             self.__setattr__(self.namespace[int(data["name"]) + 1], loads)
             self.datas.append(
                 SqleeData(loads, url=data["url"],
-                          namespace=self.namespace[int(data["name"])],
+                          namespace=self.namespace[int(data["name"]) + 1],
                           repo=self.repo)
                 )
-        if len(datas) != len(self.namespace):
-            print("数据错误: 数据与命名域不符合.")
+
+        if len(self.datas) != len(self.namespace):
+            print("数据错误: 捕获到的数据与命名域不符:\n\t命名域: %s\n\t数据: %s." % (self.namespace, model_to_data(self.datas)))
         self.datas = tuple(self.datas)
         return self.datas
 
