@@ -78,7 +78,7 @@ class django_table_objects:
                 content = json.dumps({"content": datas[i]})
                 )
         self.obj.sync()
-        return QuerySet(self.obj.columns)
+        return self.obj.columns
 
     def delete(self):
         self.obj.delete()
@@ -119,5 +119,5 @@ class Model:
         try:
             self.table = SqleeTable(name=self.tablename, repo=self.repo)
             self.objects = django_table_objects(obj=self.table)
-        except TypeError:
+        except Exception:
             pass
\ No newline at end of file
